/*
 * ER/Studio 8.0 SQL Code Generation
 * Company :      .
 * Project :      RepseApsiSistemas.DM1
 * Author :       .
 *
 * Date Created : Monday, October 25, 2021 14:12:47
 * Target DBMS : Microsoft SQL Server 2008
 */

/* 
 * TABLE: Repse_BeneficiarioServicio 
 */
 /*
DROP TABLE Repse_Empleados
DROP TABLE Repse_Contratos
DROP TABLE Repse_BeneficiarioServicio
DROP TABLE Repse_Empresa
*/

IF OBJECT_ID('Repse_BeneficiarioServicio') IS NULL

CREATE TABLE dbo.Repse_BeneficiarioServicio(
    RFC                  char(13)        NOT NULL,
    RazonSocial          varchar(200)    NULL,
    RegistroPatronal     char(11)        NOT NULL,
    Calle                varchar(150)    NULL,
    NumeroExterior       varchar(50)     NULL,
    NumeroInterior       varchar(50)     NULL,
    EntreCalle           varchar(200)    NULL,
    YCalle               varchar(200)    NULL,
    Colonia              varchar(100)    NULL,
    CodigoPostal         int             NULL,
    Municipio            varchar(200)    NULL,
    EntidadFederativa    varchar(100)    NULL,
    EMail                varchar(200)    NULL,
    Telefono             varchar(20)     NULL,
    CONSTRAINT Repse_PK3 PRIMARY KEY NONCLUSTERED (RFC,RegistroPatronal)
)
go


/* 
 * TABLE: Repse_Contratos 
 */
IF OBJECT_ID('Repse_Contratos') IS NULL

CREATE TABLE dbo.Repse_Contratos(
    Empresa               int               NOT NULL,
    RFC                   char(13)          NOT NULL,
    RegistroPatronal      char(11)          NOT NULL,
    IdContrato            bigint            IDENTITY(1,1),
    NumeroContrato        varchar(30)       NULL,
    TipoContrato          varchar(50)       NULL,
    ObjetoContrato        varchar(300)      NULL,
    MontoContrato         decimal(15, 2)    NULL,
    Vigencia              varchar(200)      NULL,
    FechaInicio           datetime          NULL,
    FechaTermino          datetime          NULL,
    EmpleadosEstimados    int               NULL,
    CalleCT               varchar(150)      NULL,
    NumeroExteriorCT      varchar(50)       NULL,
    NumeroInteriorCT      varchar(50)       NULL,
    ColoniaCT             varchar(100)      NULL,
    CodigoPostalCT        int               NULL,
    MunicipioCT           varchar(200)      NULL,
    EntidadFederativaCT   varchar(100)      NULL,
    CONSTRAINT Repse_PK4 PRIMARY KEY NONCLUSTERED (Empresa, RFC,RegistroPatronal,IdContrato)
)
go

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'CalleCT'
                        AND sysobjects.name = 'Repse_Contratos' )
    BEGIN
        ALTER TABLE dbo.Repse_Contratos ADD CalleCT VARCHAR(150) NULL
        ALTER TABLE dbo.Repse_Contratos ADD NumeroExteriorCT VARCHAR(150) NULL
        ALTER TABLE dbo.Repse_Contratos ADD NumeroInteriorCT varchar(50)  NULL
        ALTER TABLE dbo.Repse_Contratos ADD ColoniaCT varchar(100) NULL
        ALTER TABLE dbo.Repse_Contratos ADD CodigoPostalCT int NULL
        ALTER TABLE dbo.Repse_Contratos ADD MunicipioCT varchar(200) NULL
        ALTER TABLE dbo.Repse_Contratos ADD EntidadFederativaCT varchar(100) NULL
	END
GO


/* 
 * TABLE: Repse_Empleados 
 */
IF OBJECT_ID('Repse_Empleados') IS NULL
CREATE TABLE dbo.Repse_Empleados(
    Empresa               int              NOT NULL,
    RFC                   char(13)         NOT NULL,
    RegistroPatronal      char(11)         NOT NULL,
    IdContrato            bigint           NOT NULL,
    IdEmpleadoContrato    bigint           IDENTITY(1,1),
    Codigo                numeric(8, 0)    NOT NULL,
    Cuatrimestre          int              NULL,
    Tiponom               int              NULL,
    Periodo               int              NULL,
    Ayo_Operacion         int              NOT NULL,
    FechaInicial          datetime         NULL,
    FechaFinal            datetime         NULL,
    CONSTRAINT Repse_PK2 PRIMARY KEY NONCLUSTERED (Empresa, RFC,RegistroPatronal, IdContrato, IdEmpleadoContrato)
)
go


/* 
 * TABLE: Repse_Empresa 
 */
IF OBJECT_ID('Repse_Empresa') IS NULL

CREATE TABLE dbo.Repse_Empresa(
    Empresa            int             NOT NULL,
	AdministradorUnico varchar(300)    NULL,
    Email              varchar(300)    NULL,
    Telefono           varchar(50)     NULL,
	EntreCalle         varchar(300)    NULL,
	YCalle             varchar(300)    NULL,
    NumeroEscritura    varchar(50)     NULL,
    NombreNotario      varchar(200)    NULL,
    NumeroNotario      int             NULL,
    FechaEscritura     datetime        NULL,
    FolioMercantil     varchar(50)     NULL,
    RegistroSTPS       varchar(50)     NULL,
    CONSTRAINT Repse_PK1 PRIMARY KEY NONCLUSTERED (Empresa)
)
go

/* 
 * TABLE: Repse_Contratos 
 */
IF OBJECT_ID('RefRepse_Empresa1') IS NULL
ALTER TABLE Repse_Contratos ADD CONSTRAINT RefRepse_Empresa1 
    FOREIGN KEY (Empresa)
    REFERENCES Repse_Empresa(Empresa)
go

IF OBJECT_ID('RefRepse_BeneficiarioServicio2') IS NULL
ALTER TABLE Repse_Contratos ADD CONSTRAINT RefRepse_BeneficiarioServicio2 
    FOREIGN KEY (RFC,RegistroPatronal)
    REFERENCES Repse_BeneficiarioServicio(RFC,RegistroPatronal)
go


/* 
 * TABLE: Repse_Empleados 
 */
IF OBJECT_ID('RefRepse_Contratos3') IS NULL
ALTER TABLE Repse_Empleados ADD CONSTRAINT RefRepse_Contratos3 
    FOREIGN KEY (Empresa, RFC,RegistroPatronal, IdContrato)
    REFERENCES Repse_Contratos(Empresa, RFC,RegistroPatronal, IdContrato)
go


IF OBJECT_ID('dbo.Repse_GetDatosEmpresa') IS NOT NULL 
    DROP PROCEDURE dbo.Repse_GetDatosEmpresa
Go

CREATE PROCEDURE dbo.Repse_GetDatosEmpresa
    @empresa AS INTEGER 

AS

SELECT e.rfc_empresa,
       e.registro_patronal,
	   e.nombre_empresa,
	   ISNULL(re.email,'') AS 'email',
	   ISNULL(e.telefono_empresa,'') AS 'telefono',
	   pe.calleFiscal,
	   pe.NoInteriorFiscal,
	   pe.NoExteriorFiscal,
	   ISNULL(re.EntreCalle,'') AS 'EntreCalle',
	   ISNULL(re.YCalle,'') AS 'YCalle',
	   pe.ColoniaFiscal,
	   pe.CPFiscal,
	   pe.MunicipioFiscal,
	   pe.EstadoFiscal,
	   e.representante_legal,
	   ISNULL(re.AdministradorUnico,'') AS 'AdministradorUnico',
	   ISNULL(re.NumeroEscritura,'') AS 'NumeroEscritura',
	   ISNULL(re.NombreNotario,'') AS 'NombreNotario',
	   ISNULL(re.NumeroNotario,'') AS 'NumeroNotario',
	   re.FechaEscritura,
	   ISNULL(re.FolioMercantil,'') AS 'FolioMercantil',
	   ISNULL(re.RegistroSTPS,'') AS 'RegistroSTPS'
FROM dbo.empresas AS e
LEFT JOIN dbo.Repse_Empresa AS re ON e.empresa = re.empresa
LEFT JOIN dbo.parametros_empresas AS pe ON e.empresa = pe.empresa
WHERE e.empresa = @empresa

GO


IF OBJECT_ID('dbo.Repse_AddDatosEmpresa') IS NOT NULL 
    DROP PROCEDURE dbo.Repse_AddDatosEmpresa
Go

CREATE PROCEDURE dbo.Repse_AddDatosEmpresa
    @empresa AS INTEGER,
	@email AS VARCHAR(300),
	@telefono AS VARCHAR(50),
	@CalleFiscal AS VARCHAR(100),
	@NoInteriorFiscal AS VARCHAR(100),
	@NoExteriorFiscal AS VARCHAR(100),
	@EntreCalle AS VARCHAR(300),
	@YCalle AS VARCHAR(300),
	@ColoniaFiscal AS VARCHAR(100),
	@CPFiscal AS INTEGER,
	@MunicipioFiscal AS VARCHAR(100),
	@EstadoFiscal AS VARCHAR(100),
	@RepresentanteLegal AS VARCHAR(50),
	@AdministradorUnico AS VARCHAR(300),
	@NumeroEscritura AS VARCHAR(50),
	@NombreNotario AS VARCHAR(200),
	@NumeroNotario AS INTEGER,
	@FechaEscritura AS DATETIME,
	@FolioMercantil AS VARCHAR(50),
	@RegistroSTPS AS VARCHAR(50),
	@usuario AS VARCHAR(50)

AS

  SET NOCOUNT ON
  SET DATEFORMAT MDY
  DECLARE @recordId AS udtId
  SET XACT_ABORT ON

   DECLARE @funcion AS VARCHAR(20)
   DECLARE @codigo AS DECIMAL(8,0)
   DECLARE @opcion AS VARCHAR(50)
   DECLARE @opcion2 AS VARCHAR(50)
   DECLARE @opcion3 AS VARCHAR(50)
   DECLARE @password AS VARCHAR(20)
   DECLARE @registroPatronal AS VARCHAR(10)
   DECLARE @sistema AS CHAR(2)

   SET @funcion = 'RP'
   SET @opcion = 'Actualizar datos empresa REPSE'
   SET @opcion2 = ''
   SET @opcion3 = ''
   SET @password = ''
   SET @sistema = 'NO'
   SET @registroPatronal = ''
   SET @codigo = 0


  BEGIN TRANSACTION
  BEGIN TRY

  IF NOT EXISTS(SELECT empresa FROM dbo.Repse_Empresa WHERE empresa = @empresa)
     INSERT INTO dbo.Repse_Empresa
           ([Empresa]
           ,[AdministradorUnico]
           ,[Email]
           ,[Telefono]
           ,[EntreCalle]
           ,[YCalle]
           ,[NumeroEscritura]
           ,[NombreNotario]
           ,[NumeroNotario]
           ,[FechaEscritura]
           ,[FolioMercantil]
           ,[RegistroSTPS])
     VALUES
           (@Empresa
           ,@AdministradorUnico
           ,@Email
           ,@Telefono
           ,@EntreCalle
           ,@YCalle
           ,@NumeroEscritura
           ,@NombreNotario
           ,@NumeroNotario
           ,@FechaEscritura
           ,@FolioMercantil
           ,@RegistroSTPS)
  ELSE
       UPDATE dbo.Repse_Empresa SET AdministradorUnico = @AdministradorUnico,
                                    Email = @EMail,
                                    Telefono = @Telefono,
                                    EntreCalle = @EntreCalle,
                                    YCalle = @YCalle,
                                    NumeroEscritura = @NumeroEscritura,
                                    NombreNotario = @NombreNotario,
                                    NumeroNotario = @NumeroNotario,
                                    FechaEscritura = @FechaEscritura,
                                    FolioMercantil = @FolioMercantil,
                                    RegistroSTPS = @RegistroSTPS
       WHERE empresa = @Empresa

   UPDATE dbo.empresas SET representante_legal = @RepresentanteLegal,
                           telefono_empresa = @Telefono
   WHERE empresa = @Empresa			
   
   UPDATE dbo.parametros_empresas SET calleFiscal = @CalleFiscal,
	                                  NoInteriorFiscal = @NoInteriorFiscal,
	                                  NoExteriorFiscal = @NoExteriorFiscal,
									  ColoniaFiscal = @ColoniaFiscal,
	                                  CPFiscal = @CPFiscal,
	                                  MunicipioFiscal = @MunicipioFiscal,
	                                  EstadoFiscal = @EstadoFiscal
   WHERE empresa = @empresa


   INSERT  INTO dbo.bitacora
   VALUES  ( @empresa, GETDATE(), CONVERT(VARCHAR(09), GETDATE(), 114),
             @funcion, @codigo, @opcion, @opcion2, @opcion3, @usuario,
             @password, @registroPatronal, @sistema )
			     


  END TRY
  BEGIN CATCH

          IF ( XACT_STATE() ) = -1
              OR @@TRANCOUNT > 0
              ROLLBACK TRANSACTION

           SELECT  ERROR_NUMBER() AS ErrorNumber ,
                   ERROR_SEVERITY() AS ErrorSeverity ,
                   ERROR_STATE() AS ErrorState ,
                   ISNULL(ERROR_PROCEDURE(), '') AS ErrorProcedure ,
                   ERROR_LINE() AS ErrorLine ,
                   ERROR_MESSAGE() AS ErrorMessage

    END CATCH

    IF @@TRANCOUNT > 0
        COMMIT TRANSACTION


GO


IF OBJECT_ID('dbo.Repse_GetBeneficiarios') IS NOT NULL 
    DROP PROCEDURE dbo.Repse_GetBeneficiarios
Go

CREATE PROCEDURE dbo.Repse_GetBeneficiarios
AS

SELECT RFC,
       RegistroPatronal,
   	   RazonSocial,
	   EMail,
	   Telefono
FROM dbo.Repse_BeneficiarioServicio
ORDER BY RFC

GO

IF OBJECT_ID('dbo.Repse_GetBeneficiarioXRFC') IS NOT NULL 
    DROP PROCEDURE dbo.Repse_GetBeneficiarioXRFC
Go

CREATE PROCEDURE dbo.Repse_GetBeneficiarioXRFC
@RFC AS CHAR(13),
@RegistroPatronal AS CHAR(11)
AS

SELECT RFC,
       RazonSocial,
       RegistroPatronal,
       Calle,
       NumeroExterior,
       NumeroInterior,
       EntreCalle,
       YCalle,
       Colonia,
       CodigoPostal,
       Municipio,
       EntidadFederativa,
       EMail,
       Telefono
FROM dbo.Repse_BeneficiarioServicio
WHERE RFC = @RFC AND
      RegistroPatronal = @RegistroPatronal

GO

IF OBJECT_ID('dbo.Repse_AddBeneficiario') IS NOT NULL 
    DROP PROCEDURE dbo.Repse_AddBeneficiario
Go

CREATE PROCEDURE dbo.Repse_AddBeneficiario
@RFC AS char(13),
@RazonSocial AS varchar(200),
@RegistroPatronal AS char(11),
@Calle AS varchar(150),
@NumeroExterior AS varchar(50),
@NumeroInterior AS varchar(50),
@EntreCalle AS varchar(200),
@YCalle AS varchar(200),
@Colonia AS varchar(100),
@CodigoPostal AS int,
@Municipio AS varchar(200),
@EntidadFederativa AS varchar(100),
@EMail AS varchar(200),
@Telefono AS varchar(20),
@usuario AS varchar(50),
@empresa AS INTEGER

AS

  SET NOCOUNT ON
  SET DATEFORMAT MDY
  DECLARE @recordId AS udtId
  SET XACT_ABORT ON

   DECLARE @funcion AS VARCHAR(20)
   DECLARE @codigo AS DECIMAL(8,0)
   DECLARE @opcion AS VARCHAR(50)
   DECLARE @opcion2 AS VARCHAR(50)
   DECLARE @opcion3 AS VARCHAR(50)
   DECLARE @password AS VARCHAR(20)
   DECLARE @sistema AS CHAR(2)
   DECLARE @RegPat AS CHAR(10)

   SET @funcion = 'RP'
   SET @opcion = 'Actualizar Beneficiario REPSE'
   SET @opcion2 = 'RFC ' + @RFC
   SET @opcion3 = 'Registro patronal ' + @RegistroPatronal
   SET @password = ''
   SET @sistema = 'NO'
   SET @codigo = 0
   SET @RegPat = ''


  BEGIN TRANSACTION
  BEGIN TRY


IF NOT EXISTS(SELECT RFC FROM dbo.Repse_BeneficiarioServicio WHERE RFC = @RFC AND RegistroPatronal = @RegistroPatronal)
   INSERT INTO [dbo].[Repse_BeneficiarioServicio]
              ([RFC]
              ,[RazonSocial]
              ,[RegistroPatronal]
              ,[Calle]
              ,[NumeroExterior]
              ,[NumeroInterior]
              ,[EntreCalle]
              ,[YCalle]
              ,[Colonia]
              ,[CodigoPostal]
              ,[Municipio]
              ,[EntidadFederativa]
              ,[EMail]
              ,[Telefono])
   VALUES
           (@RFC 
           ,@RazonSocial
           ,@RegistroPatronal
           ,@Calle
           ,@NumeroExterior
           ,@NumeroInterior
           ,@EntreCalle
           ,@YCalle
           ,@Colonia
           ,@CodigoPostal
           ,@Municipio
           ,@EntidadFederativa
           ,@EMail
           ,@Telefono)
ELSE
   UPDATE [dbo].[Repse_BeneficiarioServicio]
          SET [RazonSocial] = @RazonSocial 
             ,[Calle] = @Calle
             ,[NumeroExterior] = @NumeroExterior
             ,[NumeroInterior] = @NumeroInterior
             ,[EntreCalle] = @EntreCalle
             ,[YCalle] = @YCalle
             ,[Colonia] = @Colonia
             ,[CodigoPostal] = @CodigoPostal
             ,[Municipio] = @Municipio
             ,[EntidadFederativa] = @EntidadFederativa
             ,[EMail] = @EMail
             ,[Telefono] = @Telefono
   WHERE RFC = @RFC AND 
         RegistroPatronal = @RegistroPatronal

   INSERT  INTO dbo.bitacora
   VALUES  ( @empresa, GETDATE(), CONVERT(VARCHAR(09), GETDATE(), 114),
             @funcion, @codigo, @opcion, @opcion2, @opcion3, @usuario,
             @password, @RegPat, @sistema )
			     


  END TRY
  BEGIN CATCH

          IF ( XACT_STATE() ) = -1
              OR @@TRANCOUNT > 0
              ROLLBACK TRANSACTION

           SELECT  ERROR_NUMBER() AS ErrorNumber ,
                   ERROR_SEVERITY() AS ErrorSeverity ,
                   ERROR_STATE() AS ErrorState ,
                   ISNULL(ERROR_PROCEDURE(), '') AS ErrorProcedure ,
                   ERROR_LINE() AS ErrorLine ,
                   ERROR_MESSAGE() AS ErrorMessage

    END CATCH

    IF @@TRANCOUNT > 0
        COMMIT TRANSACTION

GO


IF OBJECT_ID('dbo.Repse_DelBeneficiario') IS NOT NULL 
    DROP PROCEDURE dbo.Repse_DelBeneficiario
Go

CREATE PROCEDURE dbo.Repse_DelBeneficiario
@RFC AS char(13),
@RegistroPatronal AS char(11),
@usuario AS varchar(50),
@empresa AS INTEGER

AS

  SET NOCOUNT ON
  SET DATEFORMAT MDY
  DECLARE @recordId AS udtId
  SET XACT_ABORT ON

   DECLARE @funcion AS VARCHAR(20)
   DECLARE @codigo AS DECIMAL(8,0)
   DECLARE @opcion AS VARCHAR(50)
   DECLARE @opcion2 AS VARCHAR(50)
   DECLARE @opcion3 AS VARCHAR(50)
   DECLARE @password AS VARCHAR(20)
   DECLARE @sistema AS CHAR(2)
   DECLARE @RegPat AS CHAR(10)

   SET @funcion = 'RP'
   SET @opcion = 'Eliminar Beneficiario REPSE'
   SET @opcion2 = 'RFC ' + @RFC
   SET @opcion3 = 'Registro patronal ' + @RegistroPatronal
   SET @password = ''
   SET @sistema = 'NO'
   SET @codigo = 0
   SET @RegPat = ''



  BEGIN TRANSACTION
  BEGIN TRY

  DELETE dbo.Repse_BeneficiarioServicio
  WHERE RFC = @RFC AND 
        RegistroPatronal = @RegistroPatronal

  INSERT  INTO dbo.bitacora
  VALUES  ( @empresa, GETDATE(), CONVERT(VARCHAR(09), GETDATE(), 114),
            @funcion, @codigo, @opcion, @opcion2, @opcion3, @usuario,
            @password, @RegPat, @sistema )
			     


  END TRY
  BEGIN CATCH

          IF ( XACT_STATE() ) = -1
              OR @@TRANCOUNT > 0
              ROLLBACK TRANSACTION

           SELECT  ERROR_NUMBER() AS ErrorNumber ,
                   ERROR_SEVERITY() AS ErrorSeverity ,
                   ERROR_STATE() AS ErrorState ,
                   ISNULL(ERROR_PROCEDURE(), '') AS ErrorProcedure ,
                   ERROR_LINE() AS ErrorLine ,
                   ERROR_MESSAGE() AS ErrorMessage

    END CATCH

    IF @@TRANCOUNT > 0
        COMMIT TRANSACTION

GO

IF OBJECT_ID('dbo.Repse_GetContratos') IS NOT NULL 
    DROP PROCEDURE dbo.Repse_GetContratos
Go

CREATE PROCEDURE dbo.Repse_GetContratos
    @empresa AS INTEGER 

AS

SELECT rc.rfc,
       rc.registropatronal,
       rb.RazonSocial,
       rc.NumeroContrato,
       rc.FechaInicio,
       rc.FechaTermino,
	   rc.EmpleadosEstimados,
       rc.IdContrato
FROM dbo.Repse_Contratos AS rc
INNER JOIN dbo.Repse_BeneficiarioServicio AS rb ON rc.RFC = rb.RFC AND rb.RegistroPatronal = rc.RegistroPatronal
WHERE rc.empresa = @empresa
ORDER BY rc.idContrato DESC

GO

IF OBJECT_ID('dbo.Repse_GetContratoXId') IS NOT NULL 
    DROP PROCEDURE dbo.Repse_GetContratoXId
Go

CREATE PROCEDURE dbo.Repse_GetContratoXId
    @IdContrato AS BIGINT

AS

SELECT rc.Empresa
      ,rc.RFC
      ,rc.RegistroPatronal
      ,rb.RazonSocial
      ,rc.NumeroContrato
      ,rc.TipoContrato
      ,rc.ObjetoContrato
      ,rc.MontoContrato
      ,rc.Vigencia
      ,rc.FechaInicio
      ,rc.FechaTermino
      ,rc.EmpleadosEstimados
      ,rc.CalleCT
      ,rc.NumeroExteriorCT
      ,rc.NumeroInteriorCT
      ,rc.ColoniaCT
      ,rc.CodigoPostalCT
      ,rc.MunicipioCT
      ,rc.EntidadFederativaCT
FROM dbo.Repse_Contratos AS rc
INNER JOIN dbo.Repse_BeneficiarioServicio AS rb ON rc.RFC = rb.RFC AND rb.RegistroPatronal = rc.RegistroPatronal
WHERE rc.IdContrato = @IdContrato


GO


IF OBJECT_ID('dbo.Repse_AddContrato') IS NOT NULL 
    DROP PROCEDURE dbo.Repse_AddContrato
Go

CREATE PROCEDURE dbo.Repse_AddContrato
@Empresa AS int,
@idContrato AS BIGINT,
@RFC AS char(13),
@RegistroPatronal AS char(11),
@NumeroContrato AS varchar(30),
@TipoContrato AS varchar(50),
@ObjetoContrato AS varchar(300),
@MontoContrato AS decimal(15,2),
@Vigencia AS varchar(200),
@FechaInicio AS datetime,
@FechaTermino AS datetime,
@EmpleadosEstimados AS int,
@Usuario AS VARCHAR(50),
@CalleCT AS varchar(150),
@NumeroExteriorCT AS varchar(50),
@NumeroInteriorCT AS varchar(50),
@ColoniaCT AS varchar(100),
@CodigoPostalCT AS int,
@MunicipioCT AS varchar(200),
@EntidadFederativaCT AS varchar(100)

AS

  SET NOCOUNT ON
  SET DATEFORMAT MDY
  DECLARE @recordId AS udtId
  SET XACT_ABORT ON

   DECLARE @funcion AS VARCHAR(20)
   DECLARE @codigo AS DECIMAL(8,0)
   DECLARE @opcion AS VARCHAR(50)
   DECLARE @opcion2 AS VARCHAR(50)
   DECLARE @opcion3 AS VARCHAR(50)
   DECLARE @password AS VARCHAR(20)
   DECLARE @sistema AS CHAR(2)
   DECLARE @RegPat AS CHAR(10)


   SET @funcion = 'RP'

   IF @idContrato = 0
      SET @opcion = 'Agregar contrato REPSE '  
   ELSE
      SET @opcion = 'Actualizar contrato REPSE ID ' + Convert(char(6),@idContrato)  

   SET @opcion2 = 'RFC ' + @RFC
   SET @opcion3 = 'Registro patronal ' + @RegistroPatronal
   SET @password = ''
   SET @sistema = 'NO'
   SET @codigo = 0
   SET @RegPat = ''


  BEGIN TRANSACTION
  BEGIN TRY

  IF NOT EXISTS(SELECT NumeroContrato FROM dbo.Repse_Contratos WHERE IdContrato = @idContrato)
     INSERT INTO [dbo].[Repse_Contratos]
                ([Empresa]
                ,[RFC]
                ,[RegistroPatronal]
                ,[NumeroContrato]
                ,[TipoContrato]
                ,[ObjetoContrato]
                ,[MontoContrato]
                ,[Vigencia]
                ,[FechaInicio]
                ,[FechaTermino]
                ,[EmpleadosEstimados]
                ,[CalleCT]
                ,[NumeroExteriorCT]
                ,[NumeroInteriorCT]
                ,[ColoniaCT]
                ,[CodigoPostalCT]
                ,[MunicipioCT]
                ,[EntidadFederativaCT])
     VALUES
           (@Empresa 
           ,@RFC
           ,@RegistroPatronal
           ,@NumeroContrato
           ,@TipoContrato
           ,@ObjetoContrato
           ,@MontoContrato
           ,@Vigencia
           ,@FechaInicio
           ,@FechaTermino
           ,@EmpleadosEstimados
           ,@CalleCT
           ,@NumeroExteriorCT
           ,@NumeroInteriorCT
           ,@ColoniaCT
           ,@CodigoPostalCT
           ,@MunicipioCT
           ,@EntidadFederativaCT)
  ELSE
      UPDATE dbo.Repse_Contratos
          SET NumeroContrato = @NumeroContrato
             ,TipoContrato = @TipoContrato
             ,ObjetoContrato = @ObjetoContrato
             ,MontoContrato = @MontoContrato
             ,Vigencia = @Vigencia
             ,FechaInicio = @FechaInicio
             ,FechaTermino = @FechaTermino
             ,EmpleadosEstimados = @EmpleadosEstimados
             ,CalleCT = @CalleCT
             ,NumeroExteriorCT = @NumeroExteriorCT
             ,NumeroInteriorCT = @NumeroInteriorCT
             ,ColoniaCT = @ColoniaCT
             ,CodigoPostalCT = @CodigoPostalCT
             ,MunicipioCT = @MunicipioCT
             ,EntidadFederativaCT = @EntidadFederativaCT
      WHERE idContrato = @IdContrato
        

  INSERT  INTO dbo.bitacora
  VALUES  ( @empresa, GETDATE(), CONVERT(VARCHAR(09), GETDATE(), 114),
            @funcion, @codigo, @opcion, @opcion2, @opcion3, @usuario,
            @password, @RegPat, @sistema )
			     


  END TRY
  BEGIN CATCH

          IF ( XACT_STATE() ) = -1
              OR @@TRANCOUNT > 0
              ROLLBACK TRANSACTION

           SELECT  ERROR_NUMBER() AS ErrorNumber ,
                   ERROR_SEVERITY() AS ErrorSeverity ,
                   ERROR_STATE() AS ErrorState ,
                   ISNULL(ERROR_PROCEDURE(), '') AS ErrorProcedure ,
                   ERROR_LINE() AS ErrorLine ,
                   ERROR_MESSAGE() AS ErrorMessage

    END CATCH

    IF @@TRANCOUNT > 0
        COMMIT TRANSACTION


GO

IF OBJECT_ID('dbo.Repse_DelContrato') IS NOT NULL 
    DROP PROCEDURE dbo.Repse_DelContrato
Go

CREATE PROCEDURE dbo.Repse_DelContrato
@IdContrato AS BIGINT,
@RFC AS char(13),
@RegistroPatronal AS char(11),
@usuario AS varchar(50),
@empresa AS INTEGER

AS

  SET NOCOUNT ON
  SET DATEFORMAT MDY
  DECLARE @recordId AS udtId
  SET XACT_ABORT ON

   DECLARE @funcion AS VARCHAR(20)
   DECLARE @codigo AS DECIMAL(8,0)
   DECLARE @opcion AS VARCHAR(50)
   DECLARE @opcion2 AS VARCHAR(50)
   DECLARE @opcion3 AS VARCHAR(50)
   DECLARE @password AS VARCHAR(20)
   DECLARE @sistema AS CHAR(2)
   DECLARE @RegPat AS CHAR(10)


   SET @funcion = 'RP'
   SET @opcion = 'Eliminar contrato REPSE ' + CONVERT(CHAR(8),@IdContrato)
   SET @opcion2 = 'RFC ' + @RFC
   SET @opcion3 = 'Registro patronal ' + @RegistroPatronal
   SET @password = ''
   SET @sistema = 'NO'
   SET @codigo = 0
   SET @RegPat = ''


  BEGIN TRANSACTION
  BEGIN TRY

  DELETE dbo.Repse_Contratos
  WHERE idContrato = @idContrato

  INSERT  INTO dbo.bitacora
  VALUES  ( @empresa, GETDATE(), CONVERT(VARCHAR(09), GETDATE(), 114),
            @funcion, @codigo, @opcion, @opcion2, @opcion3, @usuario,
            @password, @RegPat, @sistema )
			     


  END TRY
  BEGIN CATCH

          IF ( XACT_STATE() ) = -1
              OR @@TRANCOUNT > 0
              ROLLBACK TRANSACTION

           SELECT  ERROR_NUMBER() AS ErrorNumber ,
                   ERROR_SEVERITY() AS ErrorSeverity ,
                   ERROR_STATE() AS ErrorState ,
                   ISNULL(ERROR_PROCEDURE(), '') AS ErrorProcedure ,
                   ERROR_LINE() AS ErrorLine ,
                   ERROR_MESSAGE() AS ErrorMessage

    END CATCH

    IF @@TRANCOUNT > 0
        COMMIT TRANSACTION

GO

IF OBJECT_ID('dbo.Repse_GetEmpleados') IS NOT NULL 
    DROP PROCEDURE dbo.Repse_GetEmpleados
Go

CREATE PROCEDURE dbo.Repse_GetEmpleados
    @empresa AS INTEGER 

AS

SELECT e.codigo,
       RTRIM(e.ap_paterno) + ' ' + RTRIM(e.ap_materno) + ' ' + RTRIM(e.nombre) AS 'Nombre',
	   ll.centro,
	   ll.tiponom,
	   ll.clase,
	   e.activo,
	   e.fchalta,
	   e.fch_baja  
FROM dbo.empleados AS e
INNER JOIN dbo.llaves AS ll ON e.empresa = ll.empresa AND e.codigo = ll.codigo
WHERE e.empresa = @empresa AND
	  e.pagar_nomina = 'S'
ORDER BY e.codigo

GO

IF OBJECT_ID('dbo.Repse_GetEmpleadosXContrato') IS NOT NULL 
    DROP PROCEDURE dbo.Repse_GetEmpleadosXContrato
Go

CREATE PROCEDURE dbo.Repse_GetEmpleadosXContrato
    @empresa AS INTEGER,
	@idContrato AS BIGINT 

AS

SELECT re.codigo,
       RTRIM(e.ap_paterno) + ' ' + RTRIM(e.ap_materno) + ' ' + RTRIM(e.nombre) AS 'Nombre',
       re.FechaInicial,
       re.FechaFinal,
       re.Tiponom,
       re.Periodo,
       re.Ayo_Operacion,
       re.IdEmpleadoContrato,
       re.Cuatrimestre
FROM dbo.Repse_Empleados AS re
INNER JOIN dbo.empleados AS e ON re.Empresa = e.empresa AND re.codigo = e.codigo
INNER JOIN dbo.llaves AS ll ON e.empresa = ll.empresa AND e.codigo = ll.codigo
WHERE re.empresa = @empresa AND 
      re.idContrato = @idContrato
ORDER BY re.Codigo

GO


IF OBJECT_ID('dbo.Repse_AddEmpleadosContrato') IS NOT NULL 
    DROP PROCEDURE dbo.Repse_AddEmpleadosContrato
Go

CREATE PROCEDURE dbo.Repse_AddEmpleadosContrato
@Empresa AS int,
@RFC AS char(13),
@RegistroPatronal AS char(11),
@IdContrato AS bigint,
@idEmpleadoContrato AS bigint,
@Codigo AS numeric(8,0),
@Cuatrimestre AS int,
@FechaInicial AS datetime,
@FechaFinal AS datetime,
@Usuario AS VARCHAR(50)

AS

  SET NOCOUNT ON
  SET DATEFORMAT MDY
  DECLARE @recordId AS udtId
  SET XACT_ABORT ON

   DECLARE @funcion AS VARCHAR(20)
   DECLARE @opcion AS VARCHAR(50)
   DECLARE @opcion2 AS VARCHAR(50)
   DECLARE @opcion3 AS VARCHAR(50)
   DECLARE @password AS VARCHAR(20)
   DECLARE @sistema AS CHAR(2)
   DECLARE @Tiponom AS int
   DECLARE @Periodo AS int
   DECLARE @Ayo_Operacion AS int
   DECLARE @RegPat AS CHAR(10)


   SET @funcion = 'RP'
   SET @opcion = 'Asignar empleado contrato REPSE ' + CONVERT(CHAR(8),@IdContrato)
   SET @opcion2 = 'RFC ' + @RFC
   SET @opcion3 = 'Registro patronal ' + @RegistroPatronal
   SET @password = ''
   SET @sistema = 'NO'
   SET @RegPat = ''


  BEGIN TRANSACTION
  BEGIN TRY

  SELECT @tiponom = ll.tiponom,
         @periodo = ISNULL(p.periodo,0),
		 @Ayo_operacion = ISNULL(p.ayo_operacion,0) 
  FROM dbo.llaves AS ll
  LEFT JOIN dbo.periodos AS p ON p.empresa = ll.empresa AND p.tiponom = ll.tiponom
  WHERE ll.codigo = @codigo AND 
        ll.empresa = @empresa AND
		p.estatus = 'A'

  IF NOT EXISTS(SELECT codigo FROM dbo.Repse_Empleados WHERE idEmpleadoContrato = @idEmpleadoContrato AND Empresa = @Empresa AND codigo = @Codigo)
     INSERT INTO [dbo].[Repse_Empleados]
                ([Empresa]
                ,[RFC]
                ,[RegistroPatronal]
                ,[IdContrato]
                ,[Codigo]
                ,[Cuatrimestre]
                ,[Tiponom]
                ,[Periodo]
                ,[Ayo_Operacion]
                ,[FechaInicial]
                ,[FechaFinal])
     VALUES
           (@Empresa
           ,@RFC
           ,@RegistroPatronal
           ,@IdContrato
           ,@Codigo
           ,@Cuatrimestre
           ,@Tiponom
           ,@Periodo
           ,@Ayo_Operacion
           ,@FechaInicial
           ,@FechaFinal)
  ELSE
      UPDATE dbo.Repse_Empleados
               SET Cuatrimestre = @Cuatrimestre
                  ,FechaInicial = @FechaInicial
                  ,FechaFinal = @FechaFinal
      WHERE idEmpleadoContrato = @idEmpleadoContrato AND 
	        Empresa = @Empresa AND 
			codigo = @Codigo



  INSERT  INTO dbo.bitacora
  VALUES  ( @empresa, GETDATE(), CONVERT(VARCHAR(09), GETDATE(), 114),
            @funcion, @codigo, @opcion, @opcion2, @opcion3, @usuario,
            @password, @RegPat, @sistema )
			     


  END TRY
  BEGIN CATCH

          IF ( XACT_STATE() ) = -1
              OR @@TRANCOUNT > 0
              ROLLBACK TRANSACTION

           SELECT  ERROR_NUMBER() AS ErrorNumber ,
                   ERROR_SEVERITY() AS ErrorSeverity ,
                   ERROR_STATE() AS ErrorState ,
                   ISNULL(ERROR_PROCEDURE(), '') AS ErrorProcedure ,
                   ERROR_LINE() AS ErrorLine ,
                   ERROR_MESSAGE() AS ErrorMessage

    END CATCH

    IF @@TRANCOUNT > 0
        COMMIT TRANSACTION


GO

IF OBJECT_ID('dbo.Repse_DelEmpleadoContrato') IS NOT NULL 
    DROP PROCEDURE dbo.Repse_DelEmpleadoContrato
Go

CREATE PROCEDURE dbo.Repse_DelEmpleadoContrato
@empresa AS INTEGER,
@RFC AS CHAR(13),
@RegistroPatronal AS CHAR(11),
@IdContrato AS BIGINT,
@idEmpleadoContrato AS BIGINT,
@codigo AS NUMERIC(8,0),
@usuario AS varchar(50)

AS

  SET NOCOUNT ON
  SET DATEFORMAT MDY
  DECLARE @recordId AS udtId
  SET XACT_ABORT ON

   DECLARE @funcion AS VARCHAR(20)
   DECLARE @opcion AS VARCHAR(50)
   DECLARE @opcion2 AS VARCHAR(50)
   DECLARE @opcion3 AS VARCHAR(50)
   DECLARE @password AS VARCHAR(20)
   DECLARE @sistema AS CHAR(2)
   DECLARE @RegPat AS CHAR(10)


   SET @funcion = 'RP'
   SET @opcion = 'Eliminar empleado contrato REPSE ' + CONVERT(CHAR(8),@IdContrato)
   SET @opcion2 = 'RFC ' + @RFC
   SET @opcion3 = 'Registro patronal ' + @RegistroPatronal
   SET @password = ''
   SET @sistema = 'NO'
   SET @RegPat = ''


  BEGIN TRANSACTION
  BEGIN TRY

  DELETE dbo.Repse_Empleados 
  WHERE idEmpleadoContrato = @idEmpleadoContrato AND 
        Empresa = @Empresa AND 
		codigo = @Codigo
  
  INSERT  INTO dbo.bitacora
  VALUES  ( @empresa, GETDATE(), CONVERT(VARCHAR(09), GETDATE(), 114),
            @funcion, @codigo, @opcion, @opcion2, @opcion3, @usuario,
            @password, @RegPat, @sistema )
			     


  END TRY
  BEGIN CATCH

          IF ( XACT_STATE() ) = -1
              OR @@TRANCOUNT > 0
              ROLLBACK TRANSACTION

           SELECT  ERROR_NUMBER() AS ErrorNumber ,
                   ERROR_SEVERITY() AS ErrorSeverity ,
                   ERROR_STATE() AS ErrorState ,
                   ISNULL(ERROR_PROCEDURE(), '') AS ErrorProcedure ,
                   ERROR_LINE() AS ErrorLine ,
                   ERROR_MESSAGE() AS ErrorMessage

    END CATCH

    IF @@TRANCOUNT > 0
        COMMIT TRANSACTION

GO


IF OBJECT_ID('dbo.Repse_GetContratosImportes') IS NOT NULL 
    DROP PROCEDURE dbo.Repse_GetContratosImportes
Go

CREATE PROCEDURE dbo.Repse_GetContratosImportes
@empresa AS INTEGER,
@Fecha1 AS DATETIME,
@Fecha2 AS DATETIME

AS
SELECT rfc,
SUM(MontoContrato) AS 'monto',
SUM(EmpleadosEstimados) AS 'empleados'
FROM dbo.Repse_Contratos
WHERE empresa = @empresa
GROUP BY rfc
ORDER BY rfc

GO


/*
EXECUTE dbo.DepuraTablaAvisosImssTemporalCalculo   1,'CedulaBimestral','20211117','10:51:15'
EXECUTE dbo.LlenaTablaAvisosImssTemporalCalculo    1,'CedulaBimestral','20211117','10:51:15','20210501','20210630','BIMESTRE'
EXECUTE dbo.CalculoAmortizacionInfonavit           1,6,2021
EXECUTE [dbo].[CedulaBimestralUMA]                 1,0,2021,5,6,1,'CedulaBimestral','20211117','10:51:15',0,'CedulaBimestre21',1

-- Aqui va la lectura del recordset

EXECUTE dbo.DepuraTablaAvisosImssTemporalCalculo   1,'CedulaBimestral','20211117','10:51:15'
*/

IF OBJECT_ID('dbo.Repse_GetReporteRepse01') IS NOT NULL 
    DROP PROCEDURE dbo.Repse_GetReporteRepse01
Go

CREATE PROCEDURE dbo.Repse_GetReporteRepse01
@empresa AS INTEGER,
@cuatrimestre AS INTEGER,
@ayo AS INTEGER

AS

SET NOCOUNT ON

IF OBJECT_ID('Repse_CalculoInfonavit') IS NOT NULL
   DROP TABLE dbo.Repse_CalculoInfonavit

CREATE TABLE dbo.Repse_CalculoInfonavit(
             empresa INTEGER NOT NULL,
             codigo  NUMERIC(8,0) NOT NULL,
             aportacionInfonavit NUMERIC(10,2) NULL,
             amortizacion NUMERIC(10,2) NULL,
             infonavitSinCredito NUMERIC(10,2) NULL,
             infonavitConCredito NUMERIC(10,2) NULL)

  DECLARE @tba_Resultado AS TABLE (empresa INTEGER,
                                   infonavitSinCredito DECIMAL(15,2),
								   infonavitConCredito DECIMAL(15,2),
								   Amortizacion DECIMAL(15,2) )


  DECLARE @tba_codigos AS TABLE(empresa INTEGER, codigo NUMERIC(8,0))                                   

  BEGIN TRANSACTION
  BEGIN TRY

DECLARE @fechaProceso AS DATETIME
DECLARE @horaProceso AS VARCHAR(8)
DECLARE @inicio1 AS VARCHAR(6)
DECLARE @termino1 AS VARCHAR(6)
DECLARE @inicio2 AS VARCHAR(6)
DECLARE @termino2 AS VARCHAR(6)
DECLARE @mesnon1 AS INTEGER
DECLARE @mespar1 AS INTEGER
DECLARE @mesnon2 AS INTEGER
DECLARE @mespar2 AS INTEGER
DECLARE @proceso AS VARCHAR(20)
DECLARE @simulareforma AS INT
DECLARE @cedula VARCHAR(25)
DECLARE @filtroinfonavit  AS INT   -- 1.- Todos, 2.- Slo con crdito, 3.- Slo sin crdito
DECLARE @codigo AS INTEGER
DECLARE @tipo AS INTEGER
DECLARE @inicio AS DATETIME
DECLARE @termino AS DATETIME


If @cuatrimestre = 1
   BEGIN
     SET @mesnon1 = 1 
     SET @mespar1 = 2
     SET @mesnon2 = 3 
     SET @mespar2 = 4
	 SET @inicio1 = CONVERT(CHAR(4),@ayo) + '01'
	 SET @Termino1 = CONVERT(CHAR(4),@ayo) + '02'
	 SET @inicio2 = CONVERT(CHAR(4),@ayo) + '03'
	 SET @Termino2 = CONVERT(CHAR(4),@ayo) + '04'
     SET @inicio = dbo.nvaFecha(01,01,@ayo) 
     SET @termino = dbo.fin_mes(04,@ayo)

  END 
If @cuatrimestre = 2
   BEGIN
     SET @mesnon1 = 5 
     SET @mespar1 = 6
     SET @mesnon2 = 7 
     SET @mespar2 = 8
	 SET @inicio1 = CONVERT(CHAR(4),@ayo) + '05'
	 SET @Termino1 = CONVERT(CHAR(4),@ayo) + '06'
	 SET @inicio2 = CONVERT(CHAR(4),@ayo) + '07'
	 SET @Termino2 = CONVERT(CHAR(4),@ayo) + '08'
     SET @inicio = dbo.nvaFecha(01,05,@ayo) 
     SET @termino = dbo.fin_mes(08,@ayo)

   END
If @cuatrimestre = 3
   BEGIN
     SET @mesnon1 = 9 
     SET @mespar1 = 10
     SET @mesnon2 = 11 
     SET @mespar2 = 12
	 SET @inicio1 = CONVERT(CHAR(4),@ayo) + '09'
	 SET @Termino1 = CONVERT(CHAR(4),@ayo) + '10'
	 SET @inicio2 = CONVERT(CHAR(4),@ayo) + '11'
	 SET @Termino2 = CONVERT(CHAR(4),@ayo) + '12'
     SET @inicio = dbo.nvaFecha(01,09,@ayo) 
     SET @termino = dbo.fin_mes(12,@ayo)

   END 

SET @fechaProceso = GETDATE()
SET @horaProceso = LEFT(CONVERT (time, SYSDATETIME()),8)
SET @codigo = 0
SET @simulareforma = 0
SET @proceso = 'CedulaBimestral'
SET @filtroinfonavit = 1
SET @tipo = 1


/*Primer bimestre del cuatrimestre */
EXECUTE dbo.DepuraTablaAvisosImssTemporalCalculo   @empresa,@proceso,@fechaProceso,@horaProceso
EXECUTE dbo.LlenaTablaAvisosImssTemporalCalculo    @empresa,@proceso,@fechaProceso,@horaProceso,@inicio1,@termino1,'BIMESTRE'
EXECUTE dbo.CalculoAmortizacionInfonavit           @empresa,@mespar1,@ayo


INSERT INTO dbo.Repse_CalculoInfonavit 
SELECT calculoBimestre.empresa,
       calculoBimestre.codigo,
       CASE WHEN (calculoBimestre.diastr IS NULL OR calculoBimestre.diastr = 0) AND (calculoBimestre.mov IS NULL OR calculoBimestre.mov = ' ' OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.aportacionInfonavit END AS aportacionInfonavit ,
       CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.amortizacion ELSE NULL END AS amortizacion ,
       CASE WHEN calculoBimestre.tipo = 2 THEN calculoBimestre.infonavitSinCredito ELSE 0 END AS infonavitSinCredito ,
       CASE WHEN calculoBimestre.tipo = 2 THEN calculoBimestre.infonavitConCredito ELSE 0 END AS infonavitConCredito 
FROM [dbo].[LlenaCedulaBimestralUMA](@empresa, @codigo, @ayo, @mesnon1, @mespar1, @proceso, @fechaproceso, @horaproceso, @simulareforma, @filtroinfonavit) AS calculoBimestre
LEFT JOIN dbo.rpu ON calculoBimestre.empresa = dbo.rpu.empresa AND calculoBimestre.rpu = dbo.rpu.rpu
WHERE   calculoBimestre.tipo > @tipo
ORDER BY calculoBimestre.empresa , calculoBimestre.codigo

EXECUTE dbo.DepuraTablaAvisosImssTemporalCalculo   @empresa,@proceso,@fechaProceso,@horaProceso

/*Segundo bimestre del cuatrimestre */
EXECUTE dbo.DepuraTablaAvisosImssTemporalCalculo   @empresa,@proceso,@fechaProceso,@horaProceso
EXECUTE dbo.LlenaTablaAvisosImssTemporalCalculo    @empresa,@proceso,@fechaProceso,@horaProceso,@inicio2,@termino2,'BIMESTRE'
EXECUTE dbo.CalculoAmortizacionInfonavit           @empresa,@mespar2,@ayo


INSERT INTO dbo.Repse_CalculoInfonavit 
SELECT calculoBimestre.empresa,
       calculoBimestre.codigo,
       CASE WHEN (calculoBimestre.diastr IS NULL OR calculoBimestre.diastr = 0) AND (calculoBimestre.mov IS NULL OR calculoBimestre.mov = ' ' OR calculoBimestre.mov = 'B') THEN NULL ELSE calculoBimestre.aportacionInfonavit END AS aportacionInfonavit ,
       CASE WHEN calculoBimestre.cuentaEmpleado = 1 THEN calculoBimestre.amortizacion ELSE NULL END AS amortizacion ,
       CASE WHEN calculoBimestre.tipo = 2 THEN calculoBimestre.infonavitSinCredito ELSE 0 END AS infonavitSinCredito ,
       CASE WHEN calculoBimestre.tipo = 2 THEN calculoBimestre.infonavitConCredito ELSE 0 END AS infonavitConCredito 
FROM [dbo].[LlenaCedulaBimestralUMA](@empresa, @codigo, @ayo, @mesnon2, @mespar2, @proceso, @fechaproceso, @horaproceso, @simulareforma, @filtroinfonavit) AS calculoBimestre
LEFT JOIN dbo.rpu ON calculoBimestre.empresa = dbo.rpu.empresa AND calculoBimestre.rpu = dbo.rpu.rpu
WHERE   calculoBimestre.tipo > @tipo
ORDER BY calculoBimestre.empresa , calculoBimestre.codigo

EXECUTE dbo.DepuraTablaAvisosImssTemporalCalculo   @empresa,@proceso,@fechaProceso,@horaProceso

    INSERT INTO @tba_codigos
	SELECT DISTINCT rpe.empresa,rpe.codigo 
	FROM dbo.Repse_Contratos AS rc
	INNER JOIN dbo.Repse_Empleados AS rpe ON rpe.empresa = rc.empresa AND rc.IdContrato = rpe.IdContrato
	WHERE rc.empresa = @empresa 
	       AND ((rc.FechaInicio <= @inicio AND rc.FechaTermino >= @inicio AND rc.FechaInicio <= @termino)
           OR (rc.FechaInicio >= @inicio AND rc.FechaTermino <= @termino)
           OR (rc.FechaInicio >= @inicio AND rc.FechaInicio <= @termino AND rc.FechaTermino >= @termino)
           OR (rc.FechaInicio <= @inicio AND rc.FechaTermino >= @termino))   

    INSERT INTO @tba_resultado
    SELECT rpi.empresa,
	       SUM(ISNULL(rpi.infonavitSinCredito,0)) AS 'infonavitSinCredito',
	       SUM(ISNULL(rpi.infonavitConCredito,0)) AS 'infonavitConCredito',
	       SUM(ISNULL(rpi.Amortizacion,0)) AS 'Amortizacion'
    FROM dbo.Repse_CalculoInfonavit AS rpi 
	INNER JOIN @tba_codigos AS rpe ON rpe.empresa = rpi.empresa AND rpe.codigo = rpi.codigo
	WHERE rpi.empresa = @empresa --AND
	      --rpe.cuatrimestre = @cuatrimestre AND
		  --year(rpe.fechainicial) = @ayo
    GROUP BY rpi.empresa 

--	      rpe.cuatrimestre = @cuatrimestre AND
--		  year(rpe.fechainicial) = @ayo

   SELECT @cuatrimestre AS 'Cuatrimestre',
          @ayo AS 'Ayo',
          RTRIM(LTRIM(e.rfc_empresa)) AS 'RFC_Empresa',
  	      RTRIM(e.nombre_empresa) AS 'Empresa',
	      ISNULL(re.email,'') AS 'email',
	      ISNULL(e.telefono_empresa,'') AS 'telefono',
          e.registro_patronal,
	      pe.calleFiscal,
	      pe.NoExteriorFiscal,
 	      pe.NoInteriorFiscal,
	      ISNULL(re.EntreCalle,'') AS 'EntreCalle',
	      ISNULL(re.YCalle,'') AS 'YCalle',
	      pe.ColoniaFiscal,
	      pe.CPFiscal,
	      pe.MunicipioFiscal,
	      pe.EstadoFiscal,
	      e.representante_legal,
	      ISNULL(re.AdministradorUnico,'') AS 'AdministradorUnico',
	      ISNULL(re.NumeroEscritura,'') AS 'NumeroEscritura',
	      ISNULL(re.NombreNotario,'') AS 'NombreNotario',
	      ISNULL(re.NumeroNotario,'') AS 'NumeroNotario',
	      re.FechaEscritura,
	      ISNULL(re.FolioMercantil,'') AS 'FolioMercantil',
		  ISNULL(tr.infonavitSinCredito,0) AS 'infonavitSinCredito',
		  ISNULL(tr.infonavitConCredito,0) AS 'infonavitConCredito',
		  ISNULL(tr.Amortizacion,0) AS 'Amortizacion',
	      ISNULL(re.RegistroSTPS,'') AS 'RegistroSTPS'
    FROM dbo.empresas AS e
    LEFT JOIN dbo.Repse_Empresa AS re ON e.empresa = re.empresa
    LEFT JOIN dbo.parametros_empresas AS pe ON e.empresa = pe.empresa
	LEFT JOIN @tba_resultado AS tr ON e.empresa = tr.empresa
    WHERE e.empresa = @empresa

  END TRY
  BEGIN CATCH

          IF ( XACT_STATE() ) = -1
              OR @@TRANCOUNT > 0
              ROLLBACK TRANSACTION

           SELECT  ERROR_NUMBER() AS ErrorNumber ,
                   ERROR_SEVERITY() AS ErrorSeverity ,
                   ERROR_STATE() AS ErrorState ,
                   ISNULL(ERROR_PROCEDURE(), '') AS ErrorProcedure ,
                   ERROR_LINE() AS ErrorLine ,
                   ERROR_MESSAGE() AS ErrorMessage

    END CATCH

    IF @@TRANCOUNT > 0
        COMMIT TRANSACTION

GO

IF OBJECT_ID('dbo.Repse_GetReporteRepse02') IS NOT NULL 
    DROP PROCEDURE dbo.Repse_GetReporteRepse02
Go

CREATE PROCEDURE dbo.Repse_GetReporteRepse02
@empresa AS INTEGER,
@cuatrimestre AS INTEGER,
@ayo AS INTEGER

AS

SET NOCOUNT ON

DECLARE @inicio AS DATETIME
DECLARE @termino AS DATETIME

If @cuatrimestre = 1
   BEGIN
      SET @inicio = dbo.nvaFecha(01,01,@ayo) 
	  SET @termino = dbo.fin_mes(04,@ayo)
  END 
If @cuatrimestre = 2
   BEGIN
      SET @inicio = dbo.nvaFecha(01,05,@ayo) 
	  SET @termino = dbo.fin_mes(08,@ayo)
   END
If @cuatrimestre = 3
   BEGIN
      SET @inicio = dbo.nvaFecha(01,09,@ayo) 
	  SET @termino = dbo.fin_mes(12,@ayo)
   END 

DECLARE @Fecha9999 AS DATETIME
SET @Fecha9999 = '99991231'

SELECT @cuatrimestre AS 'Cuatrimestre',
       @ayo AS 'Ayo',
       RTRIM(LTRIM(e.rfc_empresa)) AS 'RFC_Empresa', 
       rc.NumeroContrato,
	   rc.tipoContrato,
	   rc.ObjetoContrato,
	   rc.MontoContrato,
	   rc.Vigencia,
       rc.FechaInicio,
       CASE WHEN YEAR(rc.FechaTermino) = 2999 THEN @Fecha9999 ELSE rc.FechaTermino END AS 'FechaTermino',
	   rc.EmpleadosEstimados,
       RTRIM(LTRIM(rc.rfc)) AS 'RFC',	   
       rb.RazonSocial,
       rc.registropatronal,
	   rb.Calle,
       rb.NumeroExterior,
       rb.NumeroInterior,
       rb.EntreCalle,
       rb.YCalle,
       rb.Colonia,
       rb.CodigoPostal,
       rb.Municipio,
       rb.EntidadFederativa,
       rb.EMail,
       rb.Telefono
FROM dbo.Repse_Contratos AS rc
INNER JOIN dbo.empresas AS e ON rc.empresa = e.empresa
INNER JOIN dbo.Repse_BeneficiarioServicio AS rb ON rc.RFC = rb.RFC AND rb.RegistroPatronal = rc.RegistroPatronal
WHERE rc.empresa = @empresa 
      AND ((rc.FechaInicio <= @inicio AND rc.FechaTermino >= @inicio AND rc.FechaInicio <= @termino)
           OR (rc.FechaInicio >= @inicio AND rc.FechaTermino <= @termino)
           OR (rc.FechaInicio >= @inicio AND rc.FechaInicio <= @termino AND rc.FechaTermino >= @termino)
           OR (rc.FechaInicio <= @inicio AND rc.FechaTermino >= @termino))   
ORDER BY rb.RFC DESC



GO


IF OBJECT_ID('dbo.Repse_GetReporteRepse03') IS NOT NULL 
    DROP PROCEDURE dbo.Repse_GetReporteRepse03
Go

CREATE PROCEDURE dbo.Repse_GetReporteRepse03
@empresa AS INTEGER,
@cuatrimestre AS INTEGER,
@ayo AS INTEGER

AS

SET NOCOUNT ON

DECLARE @inicio AS DATETIME
DECLARE @termino AS DATETIME
DECLARE @mes1 AS INTEGER
DECLARE @mes2 AS INTEGER
DECLARE @mes3 AS INTEGER
DECLARE @mes4 AS INTEGER
DECLARE @Salmin AS DECIMAL(10,2)
DECLARE @fecha1 AS DATETIME
DECLARE @fecha2 AS DATETIME
DECLARE @fecha3 AS DATETIME
DECLARE @fecha4 AS DATETIME
DECLARE @Bimestre1 AS VARCHAR(50)
DECLARE @Bimestre2 AS VARCHAR(50)
DECLARE @nBim01 AS INTEGER
DECLARE @nBim02 AS INTEGER
DECLARE @Tope1_25 AS DECIMAL(10,2)
DECLARE @Tope2_25 AS DECIMAL(10,2)

If @cuatrimestre = 1
   BEGIN
      SET @inicio = dbo.nvaFecha(01,01,@ayo) 
	  SET @termino = dbo.fin_mes(04,@ayo)
	  SET @mes1 = 1
	  SET @mes2 = 2
	  SET @mes3 = 3
	  SET @mes4 = 4
	  SET @fecha1 = dbo.nvaFecha(01,01,@ayo) 
	  SET @fecha2 = dbo.fin_mes(02,@ayo)
	  SET @fecha3 = dbo.nvaFecha(01,03,@ayo) 
	  SET @fecha4 = dbo.fin_mes(04,@ayo)
	  SET @nBim01 = 1
	  SET @nBim02 = 2
	  SET @Bimestre1	 = 'PRIMER BIMESTRE'
	  SET @Bimestre2	 = 'SEGUNDO BIMESTRE'

  END 
If @cuatrimestre = 2
   BEGIN
      SET @inicio = dbo.nvaFecha(01,05,@ayo) 
	  SET @termino = dbo.fin_mes(08,@ayo)
	  SET @mes1 = 5
	  SET @mes2 = 6
	  SET @mes3 = 7
	  SET @mes4 = 8
	  SET @fecha1 = dbo.nvaFecha(01,05,@ayo) 
	  SET @fecha2 = dbo.fin_mes(06,@ayo)
	  SET @fecha3 = dbo.nvaFecha(01,07,@ayo) 
	  SET @fecha4 = dbo.fin_mes(08,@ayo)
	  SET @nBim01 = 3
	  SET @nBim02 = 4
	  SET @Bimestre1	 = 'TERCER BIMESTRE'
	  SET @Bimestre2	 = 'CUARTO BIMESTRE'
   END
If @cuatrimestre = 3
   BEGIN
      SET @inicio = dbo.nvaFecha(01,09,@ayo) 
	  SET @termino = dbo.fin_mes(12,@ayo)
	  SET @mes1 = 9
	  SET @mes2 = 10
	  SET @mes3 = 11
	  SET @mes4 = 12
	  SET @fecha1 = dbo.nvaFecha(01,09,@ayo) 
	  SET @fecha2 = dbo.fin_mes(10,@ayo)
	  SET @fecha3 = dbo.nvaFecha(01,11,@ayo) 
	  SET @fecha4 = dbo.fin_mes(12,@ayo)
	  SET @nBim01 = 5
	  SET @nBim02 = 6
	  SET @Bimestre1	 = 'QUINTO BIMESTRE'
	  SET @Bimestre2	 = 'SEXTO BIMESTRE'
   END 

SELECT @Tope1_25 = Tope25Veces 
FROM dbo.ObtieneSalarioUMAporFechaFuncion( @empresa,@fecha2)

SELECT @Tope2_25 = Tope25Veces 
FROM dbo.ObtieneSalarioUMAporFechaFuncion( @empresa,@fecha4)

/*
SELECT @Salmin = zona_a FROM dbo.getminimuMWage(@mes4,@ayo)

EXECUTE dbo.asp_calcular_salario_variables @empresa,@ayo,@mes1,@mes2,@fecha2,@fecha2,@salmin,'N','N'

EXECUTE dbo.asp_calcular_salario_variables @empresa,@ayo,@mes3,@mes4,@fecha4,@fecha4,@salmin,'N','N'
*/
/*
SELECT TOP 1 @nBim01 AS 'Cuatrimestre',
       @ayo AS 'Ayo',
       RTRIM(LTRIM(e.rfc_empresa)) AS 'RFC_Empresa', 
       rc.NumeroContrato,
	   e.registro_patronal,
	   tra.afiliacion + tra.digvera AS 'NSS',
	   @Bimestre1 AS 'calle',
       '0' AS 'NumeroExterior',
       '0' AS 'NumeroInterior',
       '0' AS 'Colonia',
       0 AS 'CodigoPostal',
       '0' AS 'Municipio',
       rc.EntidadFederativaCT,
	   0 AS 'ImporteIntegrable',
	   0 AS 'ImporteFijo',
	   0 AS 'Incapacidades',
	   0 AS 'ImporteNoIntegrable',
	   0 AS 'SBC',
	   re.codigo,
  	   0 AS 'Bimestre'
FROM dbo.Repse_Contratos AS rc
INNER JOIN dbo.empresas AS e ON rc.empresa = e.empresa
INNER JOIN dbo.Repse_BeneficiarioServicio AS rb ON rc.RFC = rb.RFC AND rb.RegistroPatronal = rc.RegistroPatronal
INNER JOIN dbo.Repse_Empleados AS re ON rc.empresa = re.empresa AND rc.IdContrato = re.IdContrato
INNER JOIN dbo.empleados AS tra ON re.empresa = tra.empresa AND re.codigo = tra.codigo
WHERE rc.empresa = @empresa
      AND ((rc.FechaInicio <= @inicio AND rc.FechaTermino >= @inicio AND rc.FechaInicio <= @termino)
           OR (rc.FechaInicio >= @inicio AND rc.FechaTermino <= @termino)
           OR (rc.FechaInicio >= @inicio AND rc.FechaInicio <= @termino AND rc.FechaTermino >= @termino)
           OR (rc.FechaInicio <= @inicio AND rc.FechaTermino >= @termino))   

UNION ALL
*/
SELECT DISTINCT
       @cuatrimestre AS 'Cuatrimestre',
       @ayo AS 'Ayo',
	   @nBim01 AS 'Bimestre',
       RTRIM(LTRIM(e.rfc_empresa)) AS 'RFC_Empresa', 
       rc.NumeroContrato,
	   e.registro_patronal,
	   tra.afiliacion + tra.digvera AS 'NSS',
	   rc.CalleCT,
       rc.NumeroExteriorCT,
       rc.NumeroInteriorCT,
       rc.ColoniaCT,
       rc.CodigoPostalCT,
       rc.MunicipioCT,
       rc.EntidadFederativaCT,
	   ISNULL(pv.importeVariable,0) AS 'ImporteIntegrable',
	   ISNULL(pf.ImporteFijo,0) AS 'ImporteFijo',
	   ISNULL(inc.Incapacidades,0) AS 'Incapacidades',
	   ISNULL(pint.importeNoIntegrable,0) AS 'ImporteNoIntegrable',
	   CASE WHEN ISNULL(sbc.SalarioBaseCot,0) > @tope1_25 THEN @Tope1_25 ELSE ISNULL(sbc.SalarioBaseCot,0) END AS 'SBC',
	   re.codigo
FROM dbo.Repse_Contratos AS rc
INNER JOIN dbo.empresas AS e ON rc.empresa = e.empresa
INNER JOIN dbo.Repse_BeneficiarioServicio AS rb ON rc.RFC = rb.RFC AND rb.RegistroPatronal = rc.RegistroPatronal
INNER JOIN dbo.Repse_Empleados AS re ON rc.empresa = re.empresa AND rc.IdContrato = re.IdContrato
INNER JOIN dbo.empleados AS tra ON re.empresa = tra.empresa AND re.codigo = tra.codigo
OUTER APPLY (SELECT SUM(pv.variaimss) AS importeVariable
             FROM dbo.kardex_anual AS pv
			 WHERE pv.empresa = re.empresa
			       AND pv.codigo = re.codigo
				   AND pv.tpago_desc = 'P'
				   AND pv.fch_pago >= @Fecha1
				   AND pv.fch_pago <= @Fecha2) AS pv

OUTER APPLY (SELECT SUM(CASE WHEN pf.tpago_desc = 'P' THEN pf.importe ELSE pf.importe * -1 END) AS importeFijo
             FROM dbo.kardex_anual AS pf
			 WHERE pf.empresa = re.empresa
			       AND pf.codigo = re.codigo
				   AND pf.num_conc IN (1,2,3,4,5,6,7,16,17,30,108,109,110,111)   --(1,2,3,4,5,6,7,27,30,31,37,38)
				   AND pf.fch_pago >= @Fecha1
				   AND pf.fch_pago <= @Fecha2
				   AND pf.variaimss = 0) AS pf

OUTER APPLY (SELECT SUM(inc.dias) AS Incapacidades
             FROM dbo.kardex_anual AS Inc
			 WHERE inc.empresa = re.empresa
			       AND inc.codigo = re.codigo
				   AND inc.num_conc IN (109,110,111)
				   AND inc.fch_pago >= @Fecha1
				   AND inc.fch_pago <= @Fecha2 ) AS inc

OUTER APPLY (SELECT SUM(pint.importe) AS importeNoIntegrable
             FROM dbo.kardex_anual AS pint
			 WHERE pint.empresa = re.empresa
			       AND pint.codigo = re.codigo
				   AND pint.num_conc NOT IN (1,2,3,4,5,6,7,16,17,30) --(1,2,3,4,5,6,7,27,30,31,37,38)
				   AND pint.fch_pago >= @Fecha1
				   AND pint.fch_pago <= @Fecha2
				   AND pint.tpago_desc ='P'
				   AND pint.variaimss = 0) AS pint

OUTER APPLY (SELECT TOP 1 sbc.saldiaint AS SalarioBaseCot
             FROM dbo.avisos_imss AS sbc
			 WHERE sbc.empresa = re.empresa
			       AND sbc.codigo = re.codigo
				   AND sbc.fch_mov >= @Fecha1
				   AND sbc.fch_mov <= @Fecha2
				   AND sbc.mov <> 'B'
				   ORDER BY sbc.fch_mov DESC, sbc.serial DESC) AS sbc

WHERE rc.empresa = @empresa
      AND ((rc.FechaInicio <= @inicio AND rc.FechaTermino >= @inicio AND rc.FechaInicio <= @termino)
           OR (rc.FechaInicio >= @inicio AND rc.FechaTermino <= @termino)
           OR (rc.FechaInicio >= @inicio AND rc.FechaInicio <= @termino AND rc.FechaTermino >= @termino)
           OR (rc.FechaInicio <= @inicio AND rc.FechaTermino >= @termino))   
UNION ALL
/*
SELECT TOP 1 @nBim02 AS 'Cuatrimestre',
       @ayo AS 'Ayo',
       RTRIM(LTRIM(e.rfc_empresa)) AS 'RFC_Empresa', 
       rc.NumeroContrato,
	   e.registro_patronal,
	   tra.afiliacion + tra.digvera AS 'NSS',
	   @Bimestre2 AS 'calle',
       '0' AS 'NumeroExterior',
       '0' AS 'NumeroInterior',
       '0' AS 'Colonia',
       0 AS 'CodigoPostal',
       '0' AS 'Municipio',
       rc.EntidadFederativaCT,
	   0 AS 'ImporteIntegrable',
	   0 AS 'ImporteFijo',
	   0 AS 'Incapacidades',
	   0 AS 'ImporteNoIntegrable',
	   0 AS 'SBC',
	   re.codigo,
  	   0 AS 'Bimestre'
FROM dbo.Repse_Contratos AS rc
INNER JOIN dbo.empresas AS e ON rc.empresa = e.empresa
INNER JOIN dbo.Repse_BeneficiarioServicio AS rb ON rc.RFC = rb.RFC AND rb.RegistroPatronal = rc.RegistroPatronal
INNER JOIN dbo.Repse_Empleados AS re ON rc.empresa = re.empresa AND rc.IdContrato = re.IdContrato
INNER JOIN dbo.empleados AS tra ON re.empresa = tra.empresa AND re.codigo = tra.codigo
WHERE rc.empresa = @empresa
      AND ((rc.FechaInicio <= @inicio AND rc.FechaTermino >= @inicio AND rc.FechaInicio <= @termino)
           OR (rc.FechaInicio >= @inicio AND rc.FechaTermino <= @termino)
           OR (rc.FechaInicio >= @inicio AND rc.FechaInicio <= @termino AND rc.FechaTermino >= @termino)
           OR (rc.FechaInicio <= @inicio AND rc.FechaTermino >= @termino))   


UNION ALL
*/
SELECT DISTINCT
       @cuatrimestre AS 'Cuatrimestre',
       @ayo AS 'Ayo',
	   @nBim02 AS 'Bimestre',
       RTRIM(LTRIM(e.rfc_empresa)) AS 'RFC_Empresa', 
       rc.NumeroContrato,
	   e.registro_patronal,
	   tra.afiliacion + tra.digvera AS 'NSS',
	   rc.CalleCT,
       rc.NumeroExteriorCT,
       rc.NumeroInteriorCT,
       rc.ColoniaCT,
       rc.CodigoPostalCT,
       rc.MunicipioCT,
       rc.EntidadFederativaCT,
	   ISNULL(pv.importeVariable,0) AS 'ImporteIntegrable',
	   ISNULL(pf.ImporteFijo,0) AS 'ImporteFijo',
	   ISNULL(inc.Incapacidades,0) AS 'Incapacidades',
	   ISNULL(pint.importeNoIntegrable,0) AS 'ImporteNoIntegrable',
	   CASE WHEN ISNULL(sbc.SalarioBaseCot,0) > @tope2_25 THEN @Tope2_25 ELSE ISNULL(sbc.SalarioBaseCot,0) END AS 'SBC',
	   re.codigo
FROM dbo.Repse_Contratos AS rc
INNER JOIN dbo.empresas AS e ON rc.empresa = e.empresa
INNER JOIN dbo.Repse_BeneficiarioServicio AS rb ON rc.RFC = rb.RFC AND rb.RegistroPatronal = rc.RegistroPatronal
INNER JOIN dbo.Repse_Empleados AS re ON rc.empresa = re.empresa AND rc.IdContrato = re.IdContrato
INNER JOIN dbo.empleados AS tra ON re.empresa = tra.empresa AND re.codigo = tra.codigo
OUTER APPLY (SELECT SUM(pv.variaimss) AS importeVariable
             FROM dbo.kardex_anual AS pv
			 WHERE pv.empresa = re.empresa
			       AND pv.codigo = re.codigo
				   AND pv.tpago_desc = 'P'
				   AND pv.fch_pago >= @Fecha3
				   AND pv.fch_pago <= @Fecha4) AS pv

OUTER APPLY (SELECT SUM(CASE WHEN pf.tpago_desc = 'P' THEN pf.importe ELSE pf.importe * -1 END) AS importeFijo
             FROM dbo.kardex_anual AS pf
			 WHERE pf.empresa = re.empresa
			       AND pf.codigo = re.codigo
				   AND pf.num_conc IN (1,2,3,4,5,6,7,16,17,30,108,109,110,111)   --(1,2,3,4,5,6,7,27,30,31,37,38)
				   AND pf.fch_pago >= @Fecha3
				   AND pf.fch_pago <= @Fecha4
				   AND pf.variaimss = 0) AS pf

OUTER APPLY (SELECT SUM(inc.dias) AS Incapacidades
             FROM dbo.kardex_anual AS Inc
			 WHERE inc.empresa = re.empresa
			       AND inc.codigo = re.codigo
				   AND inc.num_conc IN (109,110,111)
				   AND inc.fch_pago >= @Fecha3
				   AND inc.fch_pago <= @Fecha4 ) AS inc

OUTER APPLY (SELECT SUM(pint.importe) AS importeNoIntegrable
             FROM dbo.kardex_anual AS pint
			 WHERE pint.empresa = re.empresa
			       AND pint.codigo = re.codigo
				   AND pint.num_conc NOT IN (1,2,3,4,5,6,7,16,17,30) --(1,2,3,4,5,6,7,27,30,31,37,38)
				   AND pint.fch_pago >= @Fecha3
				   AND pint.fch_pago <= @Fecha4
				   AND pint.tpago_desc ='P'
				   AND pint.variaimss = 0) AS pint

OUTER APPLY (SELECT TOP 1 sbc.saldiaint AS SalarioBaseCot
             FROM dbo.avisos_imss AS sbc
			 WHERE sbc.empresa = re.empresa
			       AND sbc.codigo = re.codigo
				   AND sbc.fch_mov >= @Fecha3
				   AND sbc.fch_mov <= @Fecha4
				   AND sbc.mov <> 'B'
				   ORDER BY sbc.fch_mov DESC, sbc.serial DESC) AS sbc

WHERE rc.empresa = @empresa
      AND ((rc.FechaInicio <= @inicio AND rc.FechaTermino >= @inicio AND rc.FechaInicio <= @termino)
           OR (rc.FechaInicio >= @inicio AND rc.FechaTermino <= @termino)
           OR (rc.FechaInicio >= @inicio AND rc.FechaInicio <= @termino AND rc.FechaTermino >= @termino)
           OR (rc.FechaInicio <= @inicio AND rc.FechaTermino >= @termino))   
--ORDER BY rc.NumeroContrato,tra.afiliacion + tra.digvera

GO



IF OBJECT_ID('dbo.Repse_GetReporteRepse04') IS NOT NULL 
    DROP PROCEDURE dbo.Repse_GetReporteRepse04
Go

CREATE PROCEDURE dbo.Repse_GetReporteRepse04
@empresa AS INTEGER,
@cuatrimestre AS INTEGER,
@ayo AS INTEGER,
@IdContrato AS BIGINT

AS

SET NOCOUNT ON

DECLARE @inicio AS DATETIME
DECLARE @termino AS DATETIME
DECLARE @mes1 AS INTEGER
DECLARE @mes2 AS INTEGER
DECLARE @mes3 AS INTEGER
DECLARE @mes4 AS INTEGER
DECLARE @Salmin AS DECIMAL(10,2)
DECLARE @fecha1 AS DATETIME
DECLARE @fecha2 AS DATETIME
DECLARE @fecha3 AS DATETIME
DECLARE @fecha4 AS DATETIME
DECLARE @Bimestre1 AS VARCHAR(50)
DECLARE @Bimestre2 AS VARCHAR(50)
DECLARE @nBim01 AS INTEGER
DECLARE @nBim02 AS INTEGER
DECLARE @Tope1_25 AS DECIMAL(10,2)
DECLARE @Tope2_25 AS DECIMAL(10,2)

--DECLARE @Tba_Reporte AS TABLE(NSS CHAR(11), CURP VARCHAR(18), SBC DECIMAL(10,2))

If @cuatrimestre = 1
   BEGIN
      SET @inicio = dbo.nvaFecha(01,01,@ayo) 
	  SET @termino = dbo.fin_mes(04,@ayo)
	  SET @mes1 = 1
	  SET @mes2 = 2
	  SET @mes3 = 3
	  SET @mes4 = 4
	  SET @fecha1 = dbo.nvaFecha(01,01,@ayo) 
	  SET @fecha2 = dbo.fin_mes(02,@ayo)
	  SET @fecha3 = dbo.nvaFecha(01,03,@ayo) 
	  SET @fecha4 = dbo.fin_mes(04,@ayo)
	  SET @nBim01 = 1
	  SET @nBim02 = 2
	  SET @Bimestre1	 = 'PRIMER BIMESTRE'
	  SET @Bimestre2	 = 'SEGUNDO BIMESTRE'

  END 
If @cuatrimestre = 2
   BEGIN
      SET @inicio = dbo.nvaFecha(01,05,@ayo) 
	  SET @termino = dbo.fin_mes(08,@ayo)
	  SET @mes1 = 5
	  SET @mes2 = 6
	  SET @mes3 = 7
	  SET @mes4 = 8
	  SET @fecha1 = dbo.nvaFecha(01,05,@ayo) 
	  SET @fecha2 = dbo.fin_mes(06,@ayo)
	  SET @fecha3 = dbo.nvaFecha(01,07,@ayo) 
	  SET @fecha4 = dbo.fin_mes(08,@ayo)
	  SET @nBim01 = 3
	  SET @nBim02 = 4
	  SET @Bimestre1	 = 'TERCER BIMESTRE'
	  SET @Bimestre2	 = 'CUARTO BIMESTRE'
   END
If @cuatrimestre = 3
   BEGIN
      SET @inicio = dbo.nvaFecha(01,09,@ayo) 
	  SET @termino = dbo.fin_mes(12,@ayo)
	  SET @mes1 = 9
	  SET @mes2 = 10
	  SET @mes3 = 11
	  SET @mes4 = 12
	  SET @fecha1 = dbo.nvaFecha(01,09,@ayo) 
	  SET @fecha2 = dbo.fin_mes(10,@ayo)
	  SET @fecha3 = dbo.nvaFecha(01,11,@ayo) 
	  SET @fecha4 = dbo.fin_mes(12,@ayo)
	  SET @nBim01 = 5
	  SET @nBim02 = 6
	  SET @Bimestre1	 = 'QUINTO BIMESTRE'
	  SET @Bimestre2	 = 'SEXTO BIMESTRE'
   END 

SELECT @Tope1_25 = Tope25Veces 
FROM dbo.ObtieneSalarioUMAporFechaFuncion( @empresa,@fecha2)

SELECT @Tope2_25 = Tope25Veces 
FROM dbo.ObtieneSalarioUMAporFechaFuncion( @empresa,@fecha4)

/*
SELECT tra.afiliacion + tra.digvera AS 'NSS',
       tra.curp,
	   REPLACE(REPLACE(tra.nombre,'','N'),'','N') AS 'Nombre',
	   REPLACE(REPLACE(tra.ap_paterno,'','N'),'','N') AS 'Ap_paterno',
	   REPLACE(REPLACE(tra.ap_materno,'','N'),'','N') AS 'Ap_materno', 
	   CASE WHEN ISNULL(sbc.SalarioBaseCot,0) > @tope2_25 THEN @Tope2_25 ELSE ISNULL(sbc.SalarioBaseCot,0) END AS 'SBC',
	   re.FechaInicial,
	   re.codigo,
	   rc.NumeroContrato	   
*/
SELECT DISTINCT
       tra.afiliacion + tra.digvera AS 'NSS',
       tra.curp,
	   REPLACE(REPLACE(tra.nombre,'','N'),'','N') AS 'Nombre',
	   REPLACE(REPLACE(tra.ap_paterno,'','N'),'','N') AS 'Ap_paterno',
	   REPLACE(REPLACE(tra.ap_materno,'','N'),'','N') AS 'Ap_materno', 
	   CASE WHEN ISNULL(sbc.SalarioBaseCot,0) > @tope2_25 THEN @Tope2_25 ELSE ISNULL(sbc.SalarioBaseCot,0) END AS 'SBC'
FROM dbo.Repse_Contratos AS rc
INNER JOIN dbo.Repse_Empleados AS re ON rc.empresa = re.empresa AND rc.IdContrato = re.IdContrato
INNER JOIN dbo.empleados AS tra ON re.empresa = tra.empresa AND re.codigo = tra.codigo
OUTER APPLY (SELECT TOP 1 sbc.saldiaint AS SalarioBaseCot
             FROM dbo.avisos_imss AS sbc
			 WHERE sbc.empresa = re.empresa
			       AND sbc.codigo = re.codigo
				   AND sbc.fch_mov >= @inicio
				   AND sbc.fch_mov <= @termino
				   AND sbc.mov <> 'B'
				   ORDER BY sbc.fch_mov DESC, sbc.serial DESC) AS sbc


WHERE rc.empresa = @empresa
      AND ((rc.FechaInicio <= @inicio AND rc.FechaTermino >= @inicio AND rc.FechaInicio <= @termino)
           OR (rc.FechaInicio >= @inicio AND rc.FechaTermino <= @termino)
           OR (rc.FechaInicio >= @inicio AND rc.FechaInicio <= @termino AND rc.FechaTermino >= @termino)
           OR (rc.FechaInicio <= @inicio AND rc.FechaTermino >= @termino)) AND
		   RC.IdContrato = @IdContrato  
ORDER BY tra.afiliacion + tra.digvera


GO



IF OBJECT_ID('dbo.Repse_GetReporteRepse05') IS NOT NULL 
    DROP PROCEDURE dbo.Repse_GetReporteRepse05
Go

CREATE PROCEDURE dbo.Repse_GetReporteRepse05
@empresa AS INTEGER,
@mes AS INTEGER,
@ayo AS INTEGER

AS

SET NOCOUNT ON

DECLARE @inicio AS DATETIME
DECLARE @termino AS DATETIME
DECLARE @Observacion AS VARCHAR(200)

SET @inicio = dbo.nvaFecha(01,@mes,@ayo) 
SET @termino = dbo.fin_mes(@mes,@ayo)
SET @Observacion = ''




SELECT rc.RFC,
       rc.registroPatronal,
       rb.RazonSocial,
	   rc.idContrato,
	   rc.NumeroContrato,
       re.codigo,
       re.FechaInicial,
	   re.FechaFinal,
	   RTRIM(tra.ap_paterno) + ' ' + RTRIM(tra.ap_paterno) + ' ' + RTRIM(tra.nombre) AS 'Nombre',
       tra.afiliacion + tra.digvera AS 'NSS',
       tra.curp,
	   p.tiponom,
	   p.periodo,
	   p.ayo_operacion,
	   p.pago,
	   cfdi.nomina,
	   ruta.rutacfdis + SUBSTRING(e.registro_patronal,1,10) + '\' + dbo.padl(cfdi.ayo,'',4,'0') + '\' + 
	                    CASE WHEN cfdi.tiponom = 1 THEN 'SEM' 
						     WHEN cfdi.tiponom = 2 THEN 'DEC' 
						     WHEN cfdi.tiponom = 3 THEN 'CAT' 
						     WHEN cfdi.tiponom = 4 THEN 'QNA' 
						     WHEN cfdi.tiponom = 5 THEN 'MES' 
							 ELSE 'ESP' END + dbo.padl(cfdi.periodo,'',2,'0') + '\CFDIS\'  AS 'RutaCFDIS',
	   cfdi.ArchivoXML,
	   @Observacion AS 'Observaciones'
FROM dbo.Repse_Contratos AS rc
INNER JOIN dbo.Repse_Empleados AS re ON rc.empresa = re.empresa AND rc.IdContrato = re.IdContrato
INNER JOIN dbo.Repse_BeneficiarioServicio AS rb ON rc.RFC = rb.RFC
INNER JOIN dbo.empleados AS tra ON re.empresa = tra.empresa AND re.codigo = tra.codigo
INNER JOIN dbo.periodos AS p ON tra.empresa = p.empresa 
INNER JOIN dbo.ResumenCFDIs AS cfdi ON re.Empresa = cfdi.Empresa AND re.codigo = cfdi.Codigo AND p.periodo = cfdi.periodo AND p.ayo_operacion = cfdi.Ayo AND cfdi.tiponom = p.tiponom
INNER JOIN dbo.empresas AS e ON e.empresa = re.empresa AND p.pago BETWEEN @inicio AND @termino 
INNER JOIN dbo.parametros_empresas AS ruta ON re.Empresa = ruta.Empresa
WHERE rc.empresa = @empresa
      AND ((re.FechaInicial <= @inicio AND re.FechaFinal >= @inicio AND re.FechaInicial <= @termino)
           OR (re.FechaInicial >= @inicio AND re.FechaFinal <= @termino)
           OR (re.FechaInicial >= @inicio AND re.FechaInicial <= @termino AND re.FechaFinal >= @termino)
           OR (re.FechaInicial <= @inicio AND re.FechaFinal >= @termino))        
ORDER BY rc.RFC,cfdi.codigo,cfdi.periodo	     
--ORDER BY rc.NumeroContrato,tra.afiliacion + tra.digvera


GO

IF OBJECT_ID('dbo.Repse_GetReporteRepse06') IS NOT NULL 
    DROP PROCEDURE dbo.Repse_GetReporteRepse06
Go

CREATE PROCEDURE dbo.Repse_GetReporteRepse06
@empresa AS INTEGER,
@cuatrimestre AS INTEGER,
@ayo AS INTEGER

AS

SET NOCOUNT ON

DECLARE @inicio AS DATETIME
DECLARE @termino AS DATETIME
DECLARE @mes1 AS INTEGER
DECLARE @mes2 AS INTEGER
DECLARE @mes3 AS INTEGER
DECLARE @mes4 AS INTEGER
DECLARE @Salmin AS DECIMAL(10,2)
DECLARE @fecha1 AS DATETIME
DECLARE @fecha2 AS DATETIME
DECLARE @fecha3 AS DATETIME
DECLARE @fecha4 AS DATETIME
DECLARE @Bimestre1 AS VARCHAR(50)
DECLARE @Bimestre2 AS VARCHAR(50)
DECLARE @nBim01 AS INTEGER
DECLARE @nBim02 AS INTEGER
DECLARE @Tope1_25 AS DECIMAL(10,2)
DECLARE @Tope2_25 AS DECIMAL(10,2)

If @cuatrimestre = 1
   BEGIN
      SET @inicio = dbo.nvaFecha(01,01,@ayo) 
	  SET @termino = dbo.fin_mes(04,@ayo)
	  SET @mes1 = 1
	  SET @mes2 = 2
	  SET @mes3 = 3
	  SET @mes4 = 4
	  SET @fecha1 = dbo.nvaFecha(01,01,@ayo) 
	  SET @fecha2 = dbo.fin_mes(02,@ayo)
	  SET @fecha3 = dbo.nvaFecha(01,03,@ayo) 
	  SET @fecha4 = dbo.fin_mes(04,@ayo)
	  SET @nBim01 = 1
	  SET @nBim02 = 2
	  SET @Bimestre1	 = 'PRIMER BIMESTRE'
	  SET @Bimestre2	 = 'SEGUNDO BIMESTRE'

  END 
If @cuatrimestre = 2
   BEGIN
      SET @inicio = dbo.nvaFecha(01,05,@ayo) 
	  SET @termino = dbo.fin_mes(08,@ayo)
	  SET @mes1 = 5
	  SET @mes2 = 6
	  SET @mes3 = 7
	  SET @mes4 = 8
	  SET @fecha1 = dbo.nvaFecha(01,05,@ayo) 
	  SET @fecha2 = dbo.fin_mes(06,@ayo)
	  SET @fecha3 = dbo.nvaFecha(01,07,@ayo) 
	  SET @fecha4 = dbo.fin_mes(08,@ayo)
	  SET @nBim01 = 3
	  SET @nBim02 = 4
	  SET @Bimestre1	 = 'TERCER BIMESTRE'
	  SET @Bimestre2	 = 'CUARTO BIMESTRE'
   END
If @cuatrimestre = 3
   BEGIN
      SET @inicio = dbo.nvaFecha(01,09,@ayo) 
	  SET @termino = dbo.fin_mes(12,@ayo)
	  SET @mes1 = 9
	  SET @mes2 = 10
	  SET @mes3 = 11
	  SET @mes4 = 12
	  SET @fecha1 = dbo.nvaFecha(01,09,@ayo) 
	  SET @fecha2 = dbo.fin_mes(10,@ayo)
	  SET @fecha3 = dbo.nvaFecha(01,11,@ayo) 
	  SET @fecha4 = dbo.fin_mes(12,@ayo)
	  SET @nBim01 = 5
	  SET @nBim02 = 6
	  SET @Bimestre1	 = 'QUINTO BIMESTRE'
	  SET @Bimestre2	 = 'SEXTO BIMESTRE'
   END 

SELECT @Tope1_25 = Tope25Veces 
FROM dbo.ObtieneSalarioUMAporFechaFuncion( @empresa,@fecha2)

SELECT @Tope2_25 = Tope25Veces 
FROM dbo.ObtieneSalarioUMAporFechaFuncion( @empresa,@fecha4)


SELECT DISTINCT rc.NumeroContrato,rc.IdContrato,rc.Empresa	   
FROM dbo.Repse_Contratos AS rc
INNER JOIN dbo.Repse_Empleados AS re ON rc.empresa = re.empresa AND rc.IdContrato = re.IdContrato
INNER JOIN dbo.empleados AS tra ON re.empresa = tra.empresa AND re.codigo = tra.codigo
WHERE rc.empresa = @empresa
      AND ((rc.FechaInicio <= @inicio AND rc.FechaTermino >= @inicio AND rc.FechaInicio <= @termino)
           OR (rc.FechaInicio >= @inicio AND rc.FechaTermino <= @termino)
           OR (rc.FechaInicio >= @inicio AND rc.FechaInicio <= @termino AND rc.FechaTermino >= @termino)
           OR (rc.FechaInicio <= @inicio AND rc.FechaTermino >= @termino))   
ORDER BY rc.NumeroContrato


GO


IF OBJECT_ID('dbo.Repse_GetGrupoEmpresasXRFC') IS NOT NULL 
    DROP PROCEDURE dbo.Repse_GetGrupoEmpresasXRFC
Go

CREATE PROCEDURE dbo.Repse_GetGrupoEmpresasXRFC
@empresa AS INTEGER,
@cuatrimestre AS INTEGER,
@ayo AS INTEGER

AS

SET NOCOUNT ON

DECLARE @inicio AS DATETIME
DECLARE @termino AS DATETIME

If @cuatrimestre = 1
   BEGIN
      SET @inicio = dbo.nvaFecha(01,01,@ayo) 
	  SET @termino = dbo.fin_mes(04,@ayo)
  END 
If @cuatrimestre = 2
   BEGIN
      SET @inicio = dbo.nvaFecha(01,05,@ayo) 
	  SET @termino = dbo.fin_mes(08,@ayo)
   END
If @cuatrimestre = 3
   BEGIN
      SET @inicio = dbo.nvaFecha(01,09,@ayo) 
	  SET @termino = dbo.fin_mes(12,@ayo)
   END 

DECLARE @Fecha9999 AS DATETIME
SET @Fecha9999 = '99991231'

DECLARE @RFC_Matriz AS CHAR(13)

SELECT @RFC_Matriz = RTRIM(LTRIM(rfc_empresa))
FROM empresas 
WHERE empresa = @empresa
 

SELECT CASE WHEN rc.empresa = @empresa THEN 1 ELSE 0 END AS 'Seleccion',
       rc.Empresa,
       e.nombre_empresa, 
	   e.referencia,
       RTRIM(LTRIM(rc.rfc)) AS 'RFC',
       rb.RazonSocial,
	   rc.NumeroContrato,
	   rc.EmpleadosEstimados,
	   rc.IdContrato
FROM dbo.Repse_Contratos AS rc
INNER JOIN dbo.empresas AS e ON rc.empresa = e.empresa
INNER JOIN dbo.Repse_BeneficiarioServicio AS rb ON rc.RFC = rb.RFC AND rb.RegistroPatronal = rc.RegistroPatronal
WHERE RTRIM(LTRIM(e.rfc_empresa)) = @RFC_Matriz
      AND ((rc.FechaInicio <= @inicio AND rc.FechaTermino >= @inicio AND rc.FechaInicio <= @termino)
           OR (rc.FechaInicio >= @inicio AND rc.FechaTermino <= @termino)
           OR (rc.FechaInicio >= @inicio AND rc.FechaInicio <= @termino AND rc.FechaTermino >= @termino)
           OR (rc.FechaInicio <= @inicio AND rc.FechaTermino >= @termino))   
ORDER BY rc.Empresa 



GO


IF OBJECT_ID('dbo.Repse_GetReporteRepse07') IS NOT NULL 
    DROP PROCEDURE dbo.Repse_GetReporteRepse07
Go

CREATE PROCEDURE dbo.Repse_GetReporteRepse07
@empresa AS INTEGER,
@cuatrimestre AS INTEGER,
@ayo AS INTEGER

AS

SET NOCOUNT ON

DECLARE @inicio AS DATETIME
DECLARE @termino AS DATETIME

If @cuatrimestre = 1
   BEGIN
      SET @inicio = dbo.nvaFecha(01,01,@ayo) 
	  SET @termino = dbo.fin_mes(04,@ayo)
  END 
If @cuatrimestre = 2
   BEGIN
      SET @inicio = dbo.nvaFecha(01,05,@ayo) 
	  SET @termino = dbo.fin_mes(08,@ayo)
   END
If @cuatrimestre = 3
   BEGIN
      SET @inicio = dbo.nvaFecha(01,09,@ayo) 
	  SET @termino = dbo.fin_mes(12,@ayo)
   END 

DECLARE @Fecha9999 AS DATETIME
SET @Fecha9999 = '99991231'

DECLARE @RFC_Matriz AS CHAR(13)

SELECT @RFC_Matriz = RTRIM(LTRIM(rfc_empresa))
FROM empresas 
WHERE empresa = @empresa
 

SELECT DISTINCT rc.NumeroContrato,rc.IdContrato,rc.Empresa	   
FROM dbo.Repse_Contratos AS rc
INNER JOIN dbo.empresas AS e ON rc.empresa = e.empresa
INNER JOIN dbo.Repse_BeneficiarioServicio AS rb ON rc.RFC = rb.RFC AND rb.RegistroPatronal = rc.RegistroPatronal
WHERE RTRIM(LTRIM(e.rfc_empresa)) = @RFC_Matriz
      AND ((rc.FechaInicio <= @inicio AND rc.FechaTermino >= @inicio AND rc.FechaInicio <= @termino)
           OR (rc.FechaInicio >= @inicio AND rc.FechaTermino <= @termino)
           OR (rc.FechaInicio >= @inicio AND rc.FechaInicio <= @termino AND rc.FechaTermino >= @termino)
           OR (rc.FechaInicio <= @inicio AND rc.FechaTermino >= @termino))   
ORDER BY rc.Empresa,rc.NumeroContrato 



GO


PRINT 'GO' 

GO